"""Added predefined response templates

Revision ID: f36705415cd9
Revises: 3e84bb67bced
Create Date: 2025-04-14 15:44:36.881283

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from alembic.context import get_context

from core.utils import current_utc_time

# revision identifiers, used by Alembic.
revision: str = 'f36705415cd9'
down_revision: Union[str, None] = '3e84bb67bced'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    # Add SYSTEM_DEFINED response templates through insert statement
    connection = op.get_bind()
    connection.execute(
        sa.text(f"ALTER TABLE response_template ADD COLUMN `type` VARCHAR(255) NOT NULL DEFAULT 'USER_DEFINED'")
    )
    op.create_index(f'ix_response_template_type', 'response_template', ['type'])
    connection.execute(
        sa.text("""
                INSERT INTO response_template (response, description, type, status, create_time, update_time)
                VALUES 
                    ('I couldn''t respond to that input. Please try rephrasing or let me know how I can assist you differently.',
                     'Standard response for unclear or ambiguous input', 'SYSTEM_DEFINED', 1, :now, :now),
                    ('I''m unable to share that message due to privacy settings. Let me know if I can help with anything else.',
                     'Response for privacy-related content restrictions', 'SYSTEM_DEFINED', 1, :now, :now),
                    ('This topic isn''t relevant to our discussion. Please ask something else I can help with.',
                     'Response for off-topic or irrelevant queries', 'SYSTEM_DEFINED', 1, :now, :now),
                    ('I''m unable to respond to that request due to content guidelines. Let me know if there''s anything else I can assist you with.',
                     'Response for content that violates guidelines', 'SYSTEM_DEFINED', 1, :now, :now)
            """),
        {"now": current_utc_time()}
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    # Delete SYSTEM_DEFINED response templates through delete statement
    connection = op.get_bind()
    connection.execute(sa.text("DELETE FROM response_template WHERE type = 'SYSTEM_DEFINED'"))

    # Drop index on type column
    op.drop_index(f'ix_response_template_type', table_name='response_template')
    op.drop_column('response_template', 'type')
    # ### end Alembic commands ###
